@@ -3,5 +3,5 @@ from django.urls import path
 from .views import CreateJWTSecretView
 
 urlpatterns = [
-    path('jwtsecret/', CreateJWTSecretView.as_view(), name='jwtsecret-create'),
+    path("jwtsecret/", CreateJWTSecretView.as_view(), name="jwtsecret-create")
 ]
