@@ -1,6 +1,6 @@
 from django.db import models
 from django.utils.encoding import force_text
-from django.utils.translation import gettext as _
+from django.utils.translation import ugettext as _
 
 from django_filters.filters import ChoiceFilter
 from drf_yasg import openapi
@@ -53,11 +53,6 @@ class FilterInspector(CoreAPICompatInspector):
                 if not parameter.description and help_text:
                     parameter.description = force_text(help_text)
 
-                if "max_length" in filter_field.extra:
-                    parameter.max_length = filter_field.extra["max_length"]
-                if "min_length" in filter_field.extra:
-                    parameter.min_length = filter_field.extra["min_length"]
-
         return fields
 
     def process_result(self, result, method_name, obj, **kwargs):
