@@ -15,29 +15,34 @@ class Command(BaseCommand):
     help = "Patch the error-response content types in the OAS 3 spec"
 
     def add_arguments(self, parser):
-        parser.add_argument('api-spec', help="Path to the openapi spec. Will be overwritten!")
+        parser.add_argument(
+            "api-spec", help="Path to the openapi spec. Will be overwritten!"
+        )
 
     def handle(self, **options):
-        source = options['api-spec']
-        with open(source, 'r') as infile:
+        source = options["api-spec"]
+
+        # Enforce the file to be read as UTF-8 to prevent any platform
+        # dependent encoding.
+        with open(source, "r", encoding="utf8") as infile:
             spec = yaml.safe_load(infile)
 
-        for path, methods in spec['paths'].items():
+        for path, methods in spec["paths"].items():
             for method in methods.values():
-                if 'responses' not in method:
+                if "responses" not in method:
                     continue
 
-                for status, response in method['responses'].items():
+                for status, response in method["responses"].items():
                     if not (400 <= int(status) < 600):
                         continue
 
                     content = {}
-                    for contenttype, _response in response['content'].items():
-                        if contenttype == 'application/json':
+                    for contenttype, _response in response["content"].items():
+                        if contenttype == "application/json":
                             contenttype = ERROR_CONTENT_TYPE
                         content[contenttype] = _response
 
-                    response['content'] = content
+                    response["content"] = content
 
-        with open(source, 'w') as outfile:
+        with open(source, "w", encoding="utf8") as outfile:
             yaml.dump(spec, outfile, default_flow_style=False)
